==> g2_0.23.orig.tar.gz: g2-0.23/src/X11/g2_X11_funix.h <==
/*****************************************************************************
**  This is part of the g2 library
**  Copyright (C) 1998  Ljubomir Milanovic & Horst Wagner
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/
#ifndef G2_X11_FUNIX_H
#define G2_X11_FUNIX_H

#include "g2_X11_P.h"
#include "g2_physical_device.h"


const g2_funix_fun g2_X11_funix[] = {
    { g2_Delete,          g2_X11_delete },
    { g2_Ink,             g2_X11_ink    },
    { g2_Pen,             g2_X11_pen    },
    { g2_SetBackground,   g2_X11_set_background },
    { g2_ClearPalette,    g2_X11_clear_palette },
    { g2_SetLineWidth,    g2_X11_set_line_width },
    { g2_SetDash,         g2_X11_set_dash },
    { g2_SetFontSize,     g2_X11_set_font_size },
    { g2_Clear,           g2_X11_clear },		  
    { g2_Flush,           g2_X11_flush },
    { g2_Save,            g2_X11_flush },
    { g2_Plot,            g2_X11_plot },
    { g2_Line,            g2_X11_line },	  
    { g2_PolyLine,        g2_X11_poly_line },	  
    { g2_Polygon,         g2_X11_polygon },		  
    { g2_FilledPolygon,   g2_X11_filled_polygon },
    { g2_Rectangle,       g2_X11_rectangle },	  
    { g2_FilledRectangle, g2_X11_filled_rectangle },	  
    { g2_Triangle,        g2_X11_triangle },
    { g2_FilledTriangle,  g2_X11_filled_triangle },
    { g2_Arc,             g2_X11_arc },
    { g2_FilledArc,       g2_X11_filled_arc },
    { g2_Ellipse,         g2_X11_ellipse },
    { g2_FilledEllipse,   g2_X11_filled_ellipse },
    { g2_Circle,          NULL },
    { g2_FilledCircle,    NULL },
    { g2_DrawString,      g2_X11_draw_string },
    { g2_FUNIX_NULL,      NULL } };


#endif /* G2_X11_FUNIX_H */

==> g2_0.40.orig.tar.gz: g2-0.40/src/X11/g2_X11_funix.h <==
/*****************************************************************************
**  This is part of the g2 library
**  Copyright (C) 1998  Ljubomir Milanovic & Horst Wagner
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License (version 2) as
**  published by the Free Software Foundation.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
******************************************************************************/
#ifndef _G2_X11_FUNIX_H
#define _G2_X11_FUNIX_H

#include "g2_X11_P.h"
#include "g2_physical_device.h"


const g2_funix_fun g2_X11_funix[] = {
    { g2_Delete,          g2_X11_delete },
    { g2_Ink,             g2_X11_ink    },
    { g2_Pen,             g2_X11_pen    },
    { g2_SetBackground,   g2_X11_set_background },
    { g2_ClearPalette,    g2_X11_clear_palette },
    { g2_SetLineWidth,    g2_X11_set_line_width },
    { g2_SetDash,         g2_X11_set_dash },
    { g2_SetFontSize,     g2_X11_set_font_size },
    { g2_Clear,           g2_X11_clear },		  
    { g2_Flush,           g2_X11_flush },
    { g2_Save,            g2_X11_flush },
    { g2_Plot,            g2_X11_plot },
    { g2_Line,            g2_X11_line },	  
    { g2_PolyLine,        g2_X11_poly_line },	  
    { g2_Polygon,         g2_X11_polygon },		  
    { g2_FilledPolygon,   g2_X11_filled_polygon },
    { g2_Rectangle,       g2_X11_rectangle },	  
    { g2_FilledRectangle, g2_X11_filled_rectangle },	  
    { g2_Triangle,        g2_X11_triangle },
    { g2_FilledTriangle,  g2_X11_filled_triangle },
    { g2_Arc,             g2_X11_arc },
    { g2_FilledArc,       g2_X11_filled_arc },
    { g2_Ellipse,         g2_X11_ellipse },
    { g2_FilledEllipse,   g2_X11_filled_ellipse },
    { g2_Circle,          NULL },
    { g2_FilledCircle,    NULL },
    { g2_String,          g2_X11_draw_string },
    { g2_Image,           NULL },
    { g2_FUNIX_NULL,      NULL } };


#endif /* _G2_X11_FUNIX_H */
